
# FullCalendar Day Grid Plugin

Display events on Month view or DayGrid view

[View the docs &raquo;](https://fullcalendar.io/docs/month-view)

This package was created from the [FullCalendar monorepo &raquo;](https://github.com/fullcalendar/fullcalendar)
